%define major 0
%define libname %mklibname %name %major
%define libname_devel %mklibname -d %name

Name:           cmocka
Version:        1.1.5
Release:        %mkrel 4

License:        ASL 2.0
Group:          Development/C
Summary:        Lightweight library to simplify and generalize unit tests for C
Url:            http://cmocka.org

Source0:        https://cmocka.org/files/1.1/%{name}-%{version}.tar.xz

BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  glibc-devel


%description
There are a variety of C unit testing frameworks available however many of them
are fairly complex and require the latest compiler technology. Some development
requires the use of old compilers which makes it difficult to use some unit
testing frameworks. In addition many unit testing frameworks assume the code
being tested is an application or module that is targeted to the same platform
that will ultimately execute the test. Because of this assumption many
frameworks require the inclusion of standard C library headers in the code
module being tested which may collide with the custom or incomplete
implementation of the C library utilized by the code under test.

Cmocka only requires a test application is linked with the standard C library
which minimizes conflicts with standard C library headers. Also, CMocka tries
to avoid the use of some of the newer features of C compilers.

This results in CMocka being a relatively small library that can be used to
test a variety of exotic code. If a developer wishes to simply test an
application with the latest compiler then other unit testing frameworks may be
preferable.

This is the successor of Google's Cmockery.

%package -n %{libname}
Group:          Development/C
Summary:        Lightweight library to simplify and generalize unit tests for C

%description -n %{libname}
There are a variety of C unit testing frameworks available however many of them
are fairly complex and require the latest compiler technology. Some development
requires the use of old compilers which makes it difficult to use some unit
testing frameworks. In addition many unit testing frameworks assume the code
being tested is an application or module that is targeted to the same platform
that will ultimately execute the test. Because of this assumption many
frameworks require the inclusion of standard C library headers in the code
module being tested which may collide with the custom or incomplete
implementation of the C library utilized by the code under test.

CMocka only requires a test application is linked with the standard C library
which minimizes conflicts with standard C library headers. Also, CMocka tries
to avoid the use of some of the newer features of C compilers.

This results in CMocka being a relatively small library that can be used to
test a variety of exotic code. If a developer wishes to simply test an
application with the latest compiler then other unit testing frameworks may be
preferable.

This is the successor of Google's Cmockery.

%package -n %{libname}-static-devel
Group:          Development/C
Summary:        Lightweight library to simplify and generalize unit tests for C
Requires:       %{libname_devel} = %{version}-%{release}

%description -n %{libname}-static-devel
Static version of the cmocka library.

%package -n %{libname_devel}
Group:          Development/C
Summary:        Development headers for the cmocka library
Provides:       libcmocka-devel = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}

%description -n %{libname_devel}
Development headers for the cmocka unit testing library.

%prep
%autosetup -p1

%ifarch armv7hl
# This upsets valgrind on 32bit arm
# https://bugzilla.redhat.com/show_bug.cgi?id=1699304
sed -i s/fstack-clash-protection/fno-fstack-clash-protection/g CompilerChecks.cmake
%endif

%build
%cmake \
  -DWITH_STATIC_LIB=ON \
  -DWITH_CMOCKERY_SUPPORT=ON \
  -DUNIT_TESTING=ON \
%cmake_build
%cmake_build -t doc
%cmake_build -t docs

%install
%cmake_install

%check
# The test suite doesn't automatically know to look at the "built"
# library, so we force it by creating an LD_LIBRARY_PATH
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
make -C %{_vpath_builddir} test || cat Testing/Temporary/LastTest.log

%files -n %{libname}
%doc AUTHORS README.md ChangeLog COPYING
%{_libdir}/libcmocka.so.%{major}
%{_libdir}/libcmocka.so.%{major}.*

%files -n %{libname}-static-devel
%{_libdir}/libcmocka-static.a

%files -n %{libname_devel}
%doc build/doc/html
%{_includedir}/cmocka.h
%{_includedir}/cmocka_pbc.h
%{_includedir}/cmockery/cmockery.h
%{_includedir}/cmockery/pbc.h
%{_libdir}/libcmocka.so
%{_libdir}/pkgconfig/cmocka.pc
%{_libdir}/cmake/cmocka/cmocka-config-version.cmake
%{_libdir}/cmake/cmocka/cmocka-config.cmake


%changelog
* Fri Oct 23 2020 akien <akien> 1.1.5-4.mga8
+ Revision: 1638834
- Fix build with new %%cmake_build macro

* Sun Feb 16 2020 umeabot <umeabot> 1.1.5-3.mga8
+ Revision: 1536362
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Thu Oct 17 2019 pterjan <pterjan> 1.1.5-2.mga8
+ Revision: 1454394
- Disable fstack-clash-protection on armv7hl

* Fri Apr 05 2019 shlomif <shlomif> 1.1.5-1.mga7
+ Revision: 1386114
- New version 1.1.5

* Thu Nov 22 2018 shlomif <shlomif> 1.1.3-1.mga7
+ Revision: 1333239
- New version 1.1.3

* Sat Sep 22 2018 umeabot <umeabot> 1.1.1-2.mga7
+ Revision: 1296619
- Mageia 7 Mass Rebuild

* Tue Oct 03 2017 shlomif <shlomif> 1.1.1-1.mga7
+ Revision: 1168041
- New version 1.1.1

* Thu Feb 11 2016 umeabot <umeabot> 1.0.1-4.mga6
+ Revision: 953639
- Mageia 6 Mass Rebuild

* Tue Oct 06 2015 shlomif <shlomif> 1.0.1-3.mga6
+ Revision: 886555
- Importing cmocka - thanks to Neal Gompa/Son_Goku

